Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(121)

Unified Diff: src/pdf/SkPDFShader.h

Issue 841763005: Generic PDF shader fallback (Closed) Base URL: https://chromium.googlesource.com/skia.git@master
Patch Set: win build fix Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/pdf/SkPDFDevice.cpp ('k') | src/pdf/SkPDFShader.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/pdf/SkPDFShader.h
diff --git a/src/pdf/SkPDFShader.h b/src/pdf/SkPDFShader.h
index 0b292e932a3c0dd557a81572c59df59ffc6b7a98..9c92d77d927cd463f46a8cd9e40478b135fcf3a3 100644
--- a/src/pdf/SkPDFShader.h
+++ b/src/pdf/SkPDFShader.h
@@ -33,15 +33,17 @@ public:
* unreference it when done. This is needed to accommodate the weak
* reference pattern used when the returned object is new and has no
* other references.
* @param shader The SkShader to emulate.
* @param matrix The current transform. (PDF shaders are absolutely
* positioned, relative to where the page is drawn.)
* @param surfceBBox The bounding box of the drawing surface (with matrix
* already applied).
*/
static SkPDFObject* GetPDFShader(const SkShader& shader,
const SkMatrix& matrix,
- const SkIRect& surfaceBBox);
+ const SkIRect& surfaceBBox,
+ SkScalar rasterScale);
protected:
class State;
« no previous file with comments | « src/pdf/SkPDFDevice.cpp ('k') | src/pdf/SkPDFShader.cpp » ('j') | no next file with comments »
@@ -33,15 +33,17 @@ public:
* reference pattern used when the returned object is new and has no
* other references.
- * @param shader The SkShader to emulate.
- * @param matrix The current transform. (PDF shaders are absolutely
- * positioned, relative to where the page is drawn.)
- * @param surfceBBox The bounding box of the drawing surface (with matrix
- * already applied).
+ * @param shader The SkShader to emulate.
+ * @param matrix The current transform. (PDF shaders are absolutely
+ * positioned, relative to where the page is drawn.)
+ * @param surfceBBox The bounding box of the drawing surface (with matrix
+ * already applied).
+ * @param rasterScale Additional scale to be applied for early rasterization.
*/
static SkPDFObject* GetPDFShader(const SkShader& shader,

Powered by Google App Engine
This is Rietveld 408576698